@@ -14,9 +14,10 @@ use libc::c_char;
     target_os = "fuchsia",
     target_os = "hurd",
     target_os = "illumos",
+    target_vendor = "apple",
 ))]
 use libc::dirfd;
-#[cfg(any(target_os = "fuchsia", target_os = "illumos"))]
+#[cfg(any(target_os = "fuchsia", target_os = "illumos", target_vendor = "apple"))]
 use libc::fstatat as fstatat64;
 #[cfg(any(all(target_os = "linux", not(target_env = "musl")), target_os = "hurd"))]
 use libc::fstatat64;
@@ -907,6 +908,7 @@ impl DirEntry {
             target_os = "fuchsia",
             target_os = "hurd",
             target_os = "illumos",
+            target_vendor = "apple",
         ),
         not(miri) // no dirfd on Miri
     ))]
@@ -937,6 +939,7 @@ impl DirEntry {
             target_os = "fuchsia",
             target_os = "hurd",
             target_os = "illumos",
+            target_vendor = "apple",
         )),
         miri
     ))]
@@ -1292,6 +1295,7 @@ impl File {
         target_os = "netbsd",
         target_os = "openbsd",
         target_os = "cygwin",
+        target_os = "illumos",
         target_vendor = "apple",
     ))]
     pub fn lock(&self) -> io::Result<()> {
@@ -1316,6 +1320,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "solaris",
+        target_os = "illumos",
         target_vendor = "apple",
     )))]
     pub fn lock(&self) -> io::Result<()> {
@@ -1329,6 +1334,7 @@ impl File {
         target_os = "netbsd",
         target_os = "openbsd",
         target_os = "cygwin",
+        target_os = "illumos",
         target_vendor = "apple",
     ))]
     pub fn lock_shared(&self) -> io::Result<()> {
@@ -1353,6 +1359,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "solaris",
+        target_os = "illumos",
         target_vendor = "apple",
     )))]
     pub fn lock_shared(&self) -> io::Result<()> {
@@ -1366,6 +1373,7 @@ impl File {
         target_os = "netbsd",
         target_os = "openbsd",
         target_os = "cygwin",
+        target_os = "illumos",
         target_vendor = "apple",
     ))]
     pub fn try_lock(&self) -> Result<(), TryLockError> {
@@ -1406,6 +1414,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "solaris",
+        target_os = "illumos",
         target_vendor = "apple",
     )))]
     pub fn try_lock(&self) -> Result<(), TryLockError> {
@@ -1422,6 +1431,7 @@ impl File {
         target_os = "netbsd",
         target_os = "openbsd",
         target_os = "cygwin",
+        target_os = "illumos",
         target_vendor = "apple",
     ))]
     pub fn try_lock_shared(&self) -> Result<(), TryLockError> {
@@ -1462,6 +1472,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "solaris",
+        target_os = "illumos",
         target_vendor = "apple",
     )))]
     pub fn try_lock_shared(&self) -> Result<(), TryLockError> {
@@ -1478,6 +1489,7 @@ impl File {
         target_os = "netbsd",
         target_os = "openbsd",
         target_os = "cygwin",
+        target_os = "illumos",
         target_vendor = "apple",
     ))]
     pub fn unlock(&self) -> io::Result<()> {
@@ -1502,6 +1514,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "solaris",
+        target_os = "illumos",
         target_vendor = "apple",
     )))]
     pub fn unlock(&self) -> io::Result<()> {
